import "./Stake.scss";

import { Box, Typography } from "@mui/material";
import SettingsIcon from '@mui/icons-material/Settings';
import { memo, useState, useEffect } from "react";
import { useChainId } from "wagmi";
import { useSearchParams } from "react-router-dom";

import { StakeArea } from "./components/StakeArea";

import GhostStyledIcon from "../../components/Icon/GhostIcon";
import Modal from "../../components/Modal/Modal";
import Paper from "../../components/Paper/Paper";
import TokenStack from "../../components/TokenStack/TokenStack";

const Stake = ({ chainId, address, isOpened, closeModal, connect }) => {
    const [action, setAction] = useState("STAKE");
    const [upperToken, setUpperToken] = useState("FTSO");
    const [bottomToken, setBottomToken] = useState("GHST");
    const [settingsModalOpen, setSettingsModalOpen] = useState(false);

    const setSettingsModalOpenInner = (value) => {
        setSettingsModalOpen(value);
    }

    useEffect(() => {
        switch (true) {
            case (upperToken === "FTSO" && bottomToken === "STNK"):
                setAction("STAKE")
                break;
            case (upperToken === "FTSO" && bottomToken === "GHST"):
                setAction("STAKE")
                break;
            case (upperToken === "STNK" && bottomToken === "FTSO"):
                setAction("UNSTAKE")
                break;
            case (upperToken === "GHST" && bottomToken === "FTSO"):
                setAction("UNSTAKE")
                break;
            case (upperToken === "STNK" && bottomToken === "GHST"):
                setAction("WRAP")
                break;
            case (upperToken === "GHST" && bottomToken === "STNK"):
                setAction("UNWRAP")
                break;
            default:
                setAction("STAKE")
        }
    }, [upperToken, bottomToken])

    return (
        <Modal
            headerContent={
                <Box display="flex" justifyContent="center" alignItems="center" gap="15px">
                    <Typography variant="h4">{action}</Typography>
                    <TokenStack tokens={[upperToken, bottomToken]} />
                </Box>
            }
            topLeft={
                <GhostStyledIcon
                    viewBox="0 0 23 23"
                    component={SettingsIcon}
                    style={{ cursor: "pointer" }}
                    onClick={() => setSettingsModalOpenInner(true)}
                />
            }
            open={isOpened}
            onClose={closeModal}
            maxWidth="460px"
            minHeight="200px"
        >
            <Box display="flex" alignItems="center" justifyContent="center" flexDirection="column">
                <StakeArea
                    settingsModalOpen={settingsModalOpen}
                    closeSettingModal={() => setSettingsModalOpenInner(false)}
                    upperToken={upperToken}
                    setUpperToken={setUpperToken}
                    bottomToken={bottomToken}
                    setBottomToken={setBottomToken}
                    action={action}
                    chainId={chainId}
                    address={address}
                    connect={connect}
                />
            </Box>
        </Modal>
    );
};

export default memo(Stake);
