import { useReadContract } from "wagmi";

import { useCurrentIndex } from "../staking";
import { useUniswapV2PairReserves } from "../uniswapv2";
import { DecimalBigNumber } from "../../helpers/DecimalBigNumber";
import { FTSO_DAI_LP_ADDRESSES, DAI_ADDRESSES, FTSO_ADDRESSES } from "../../constants/addresses";

export const useDaiPrice = (chainId) => {
    const daiPrice = new DecimalBigNumber(1000000000000000000n, 18);
    return daiPrice;
};

export const useFtsoPrice = (chainId) => {
    const { reserves, tokens, refetch } = useUniswapV2PairReserves(
        chainId,
        FTSO_DAI_LP_ADDRESSES[chainId],
        9,
        18,
        "FTSO",
        "GDAI",
    );

    const stableReserves = DAI_ADDRESSES[chainId].toUpperCase() === tokens.token0.toUpperCase()
        ? reserves.reserve0._value
        : DAI_ADDRESSES[chainId].toUpperCase() === tokens.token1.toUpperCase() ? reserves.reserve1._value : 0n;

    const ftsoReserves = FTSO_ADDRESSES[chainId].toUpperCase() === tokens.token0.toUpperCase()
        ? reserves.reserve0._value
        : FTSO_ADDRESSES[chainId].toUpperCase() === tokens.token1.toUpperCase() ? reserves.reserve1._value : 0n;

    let price = 0n
    if (ftsoReserves > 0n)
        price = stableReserves / ftsoReserves;

    return new DecimalBigNumber(price, 9);
};

export const useStnkPrice = (chainId) => {
    const stnkPrice = useFtsoPrice(chainId);
    return stnkPrice;
};

export const useGhstPrice = (chainId) => {
    const ftsoPrice = useFtsoPrice(chainId);
    const { currentIndex } = useCurrentIndex(chainId);

    return ftsoPrice.mul(currentIndex);
};
